.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :end-before: For more information

How the documentation is structured
------------------------------------

.. grid:: 2
    :gutter: 4

    .. grid-item-card::
        :text-align: left

        **📖 Getting Started**
        ^^^

        .. toctree::
           :maxdepth: 2

           getting_started

        +++
        New users start here. Installation and basic setup.

    .. grid-item-card::
        :text-align: left

        **🎓 Tutorial**
        ^^^

        .. toctree::
           :maxdepth: 2

           tutorial

        +++
        Step-by-step guides for typical usage patterns.

    .. grid-item-card::
        :text-align: left

        **📚 User Guide**
        ^^^

        .. toctree::
           :maxdepth: 2

           user_guide

        +++
        Detailed explanations of features and concepts.

    .. grid-item-card::
        :text-align: left

        **🔧 Reference**
        ^^^

        .. toctree::
           :maxdepth: 2

           reference

        +++
        Technical API documentation and specifications.


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
